OC.L10N.register(
    "core",
    {
    "Please select a file." : "Te rugăm să alegi un fișier.",
    "File is too big" : "Fișierul este prea mare",
    "The selected file is not an image." : "Fișierul selectat nu este o imagine.",
    "The selected file cannot be read." : "Fișierul selectat nu poate fi citit.",
    "The file was uploaded" : "Fișierul a fost încărcat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
    "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
    "Invalid file provided" : "Numele fișierului pe care l-ai oferit este invalid",
    "No image or file provided" : "Nu a fost furnizat vreo imagine sau fișier",
    "Unknown filetype" : "Tip fișier necunoscut",
    "An error occurred. Please contact your admin." : "A apărut o eroare. Te rugăm să contactezi administratorul.",
    "Invalid image" : "Imagine invalidă",
    "No temporary profile picture available, try again" : "Nu este disponibilă nicio imagine temporară a profilului, încearcă din nou",
    "No crop data provided" : "Nu există informație pentru operațiunea crop",
    "No valid crop data provided" : "Nu există informație validă pentru operațiunea crop",
    "Crop is not square" : "Selecția nu este pătrată",
    "State token does not match" : "Statusul token-ului nu se potrivește",
    "Invalid app password" : "Parolă de aplicație invalidă",
    "Could not complete login" : "Nu am putut efectua autentificarea",
    "State token missing" : "Tokenul de stare lipsește",
    "Your login token is invalid or has expired" : "Tokenul tău de autentificare este invalid sau a expirat",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Această versiune produsă de comunitatea Nextcloud nu este suportată și notificările push sunt limitate.",
    "Login" : "Autentificare",
    "Password reset is disabled" : "Resetarea parolei este dezactivată.",
    "Could not reset password because the token is expired" : "Nu s-a putut reseta parola deoarece token-ul a expirat",
    "Could not reset password because the token is invalid" : "Nu s-a putut reseta parola deoarece token-ul este invalid",
    "Password is too long. Maximum allowed length is 469 characters." : "Parola este prea lungă. Lungimea maximă este 469 caractere.",
    "%s password reset" : "%s resetare parola",
    "Password reset" : "Resetare parolă",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați butonul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați link-ul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
    "Reset your password" : "Resetați-vă parola",
    "Task not found" : "Sarcina nu a fost găsită",
    "Internal error" : "Eroare internă",
    "Not found" : "Nu a fost găsit",
    "Bad request" : "Solicitare invalidă",
    "Requested task type does not exist" : "Tipul de sarcină cerut nu există",
    "Necessary language model provider is not available" : "Furnizorul de model de limbă nu este disponibil",
    "No text to image provider is available" : "Niciun provider disponibil pentru text - imagine",
    "Image not found" : "Imagine indisponibilă",
    "No translation provider available" : "Niciun furnizor de traducere nu este disponibil",
    "Could not detect language" : "Nu a putut fi detectată limba",
    "Unable to translate" : "Nu s-a putut traduce",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Unele dintre link-urile tale partajate au fost șterse",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Din cauza unui bug de securitate, a trebuit să eliminăm unele dintre link-urile dvs. partajate. Vă rugăm să consultați link-ul pentru mai multe informații.",
    "Learn more ↗" : "Află mai multe ↗",
    "Preparing update" : "Se pregătește actualizarea",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Etapa de reparare:",
    "Repair info:" : "Informații despre reparații:",
    "Repair warning:" : "Avertisment de reparație:",
    "Repair error:" : "Eroare de reparare:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilizează actualizarea din linie de comandă, pentru că actualizarea automată este dezactivată în config.php.",
    "Turned on maintenance mode" : "Modul mentenanță a fost activat",
    "Turned off maintenance mode" : "Modul mentenanță a fost dezactivat",
    "Maintenance mode is kept active" : "Modul de mentenanță este menținut activ",
    "Updating database schema" : "Se actualizează schema bazei de date",
    "Updated database" : "Bază de date actualizată",
    "Update app \"%s\" from App Store" : "Actualizează aplicația \"%s\" din magazinul de aplicații",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Se verifică dacă schema bazei de date pentru %s poate fi actualizată (poate dura un timp îndelungat, în funcție de dimensiunea bazei de date)",
    "Updated \"%1$s\" to %2$s" : "Actualizat \"%1$s\" la %2$s",
    "Set log level to debug" : "Setează nivelul de logare la \"debug\"",
    "Reset log level" : "Resetează nivelul de logare",
    "Starting code integrity check" : "Începe verificarea integrității codului",
    "Finished code integrity check" : "Verificarea integrității codului a fost finalizată",
    "%s (incompatible)" : "%s (incompatibil)",
    "The following apps have been disabled: %s" : "Următoarele aplicații au fost dezactivate: %s",
    "Already up to date" : "Deja actualizat",
    "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Pentru mai multe detalii vedeți {linkstart}documentația ↗{linkend}.",
    "unknown text" : "text necunoscut",
    "Hello world!" : "Hello world!",
    "sunny" : "însorit",
    "Hello {name}, the weather is {weather}" : "Bună {name}, vremea este {weather}",
    "Hello {name}" : "Salut {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Acestea sunt rezultatele căutării tale<script>alert(1)</script></strong>",
    "new" : "nou",
    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în desfășurare, părăsirea acestei pagini ar putea întrerupe procesul în anumite medii.",
    "Update to {version}" : "Actualizare la {version}",
    "An error occurred." : "A apărut o eroare.",
    "Please reload the page." : "Te rugăm să reîncarci pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Actualizarea nu a reușit. Pentru mai multe informații <a href=\"{url}\">verificați postările din forum</a> pe această temă.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Actualizarea nu a reușit. Te rugăm să raportezi această problemă <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunității Nextcloud</a>.",
    "Continue to {productName}" : "Continuă la {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Actualizare efectuată. Redirectare la {productName} în %n secundă.","Actualizare efectuată. Redirectare la {productName} în %n seconde.","Actualizare efectuată. Redirectare la {productName} în %n secunde."],
    "Applications menu" : "Meniul aplicațiilor",
    "Apps" : "Aplicații",
    "More apps" : "Mai multe aplicatii",
    "_{count} notification_::_{count} notifications_" : ["{count} notificare","{count} notificări","{count} notificări"],
    "No" : "Nu",
    "Yes" : "Da",
    "Failed to add the public link to your Nextcloud" : "Eroare la adăugarea link-ului public la Nextcloud",
    "Custom date range" : "Interval particular de date",
    "Pick start date" : "Selectează o dată de început",
    "Pick end date" : "Selectează o dată de sfârșit",
    "Search in date range" : "Caută în intervalul",
    "Search everywhere" : "Caută oriunde",
    "Searching …" : "Căutare ...",
    "Start typing to search" : "Tastați pentru căutare",
    "No matching results" : "Niciun rezultat găsit",
    "Today" : "Azi",
    "Last 7 days" : "Ultimele 7 zile",
    "Last 30 days" : "Ultimele 30 de zile",
    "This year" : "Anul acesta",
    "Last year" : "Anul trecut",
    "Unified search" : "Căutare unificată",
    "Search apps, files, tags, messages" : "Caută aplicații, fișiere, etichete, mesaje",
    "Places" : "Locuri",
    "Date" : "Dată",
    "Search people" : "Caută persoane",
    "People" : "Persoane",
    "Filter in current view" : "Filtrează în vizualizarea curentă",
    "Results" : "Rezultate",
    "Load more results" : "Încarcă mai multe rezultate",
    "Search in" : "Caută în",
    "Log in" : "Autentificare",
    "Logging in …" : "Se autentifică...",
    "Log in to {productName}" : "Logare la {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Au fost detectate mai multe încercări de logare eșuate de la adresa dumneavoastră IP. De aceea, următoarea încercare va fi încetinită până la 30 de secunde.",
    "Account name or email" : "Cont utilizator sau email",
    "Server side authentication failed!" : "Autentificarea la nivel de server a eșuat!",
    "Please contact your administrator." : "Contactează-ți administratorul.",
    "Temporary error" : "Eroare temporară",
    "Please try again." : "Încercați din nou.",
    "An internal error occurred." : "A apărut o eroare internă.",
    "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
    "Password" : "Parolă",
    "Log in with a device" : "Logare cu dispozitiv",
    "Your account is not setup for passwordless login." : "Contul acesta nu este configurat pentru logare fără parolă.",
    "Your connection is not secure" : "Conexiunea este nesigură",
    "Passwordless authentication is only available over a secure connection." : "Autentificarea fără parolă este disponibilă doar în cazul conexiunilor sigure.",
    "Browser not supported" : "Browser incompatibil",
    "Passwordless authentication is not supported in your browser." : "Autentificarea fără parolă nu este suportată de browser.",
    "Reset password" : "Resetează parola",
    "Back to login" : "Înapoi la autentificare",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Password cannot be changed. Please contact your administrator." : "Parola nu s-a putut schimba. Contactați administratorul.",
    "New password" : "Noua parolă",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Fișierele tale sunt criptate. Acestea nu vor mai putea fi recuperate după resetarea parolei. Dacă nu știți cumm să procedați, contactați administratorul înainte de a continua. Sigur doriți să continuați?",
    "I know what I'm doing" : "Știu ce fac",
    "Resetting password" : "Resetez parola",
    "Schedule work & meetings, synced with all your devices." : "Organizează munca & întâlnirile, sincronizat pe toate dispozitivele.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Un loc comun pentru colegi și prieteni fără scurgeri de informații private.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicație simplă de mail, integrată cu Fișiere, Contacte și Calendar.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documente colaborative, foi de calcul și prezentări, create în Collabora Online.",
    "Distraction free note taking app." : "Aplicație simplă pentru note",
    "Recommended apps" : "Aplicații recomandate",
    "Loading apps …" : "Se încarcă aplicațiile ...",
    "Could not fetch list of apps from the App Store." : "Nu s-a putut prelua lista aplicațiilor din App Store.",
    "App download or installation failed" : "Descărcarea și instalarea aplicației a eșuat",
    "Cannot install this app because it is not compatible" : "Nu se poate instala aplicația deoarece este incompatibilă",
    "Cannot install this app" : "Nu se poate instala această aplicație",
    "Skip" : "Sari peste",
    "Installing apps …" : "Se instalează aplicațiile ...",
    "Install recommended apps" : "Instalați aplicațiile recomandate",
    "Avatar of {displayName}" : "Avatarul {displayName}",
    "Settings menu" : "Meniul Setări",
    "Loading your contacts …" : "Se încarcă contactele ...",
    "Looking for {term} …" : "Se caută  {term} …",
    "Search contacts" : "Cautare contacte",
    "Reset search" : "Resetează căutarea",
    "Search contacts …" : "Caută contacte ...",
    "Could not load your contacts" : "Nu pot încarca contactele",
    "No contacts found" : "Nu s-au găsit contacte",
    "Show all contacts" : "Arată toate contactele",
    "Install the Contacts app" : "Instalează aplicația Contacte",
    "Search" : "Căutare",
    "No results for {query}" : "Niciun rezultat pentru {query}",
    "Press Enter to start searching" : "Apăsați Enter pentru căutare",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduceți {minSearchLength} caracter sau mai multe pentru căutare","Introduceți {minSearchLength} sau mai multe caractere pentru căutare","Introduceți {minSearchLength} sau mai multe caractere pentru căutare"],
    "An error occurred while searching for {type}" : "Eroare la căutarea pentru {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Căutarea începe când tastați și navigarea în rezultate se face cu tastele săgeți",
    "Search for {name} only" : "Caută doar {name} ",
    "Loading more results …" : "Se încarcă mai multe rezultate ...",
    "Forgot password?" : "Ai uitat parola?",
    "Back to login form" : "Înapoi la forma de login",
    "Back" : "Înapoi",
    "Login form is disabled." : "Forma de login este dezactivată.",
    "More actions" : "Mai multe acțiuni",
    "Security warning" : "Alertă de securitate",
    "Storage & database" : "Stocare și baza de date",
    "Data folder" : "Director date",
    "Install and activate additional PHP modules to choose other database types." : "Instalează și activează module PHP adiționale pentru a putea alege alte tipuri de baze de date.",
    "For more details check out the documentation." : "Pentru mai multe detalii verifică documentația.",
    "Performance warning" : "Alertă de performanță",
    "You chose SQLite as database." : "Ați ales SQLite ca bază de date.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ar trebui folosit doar pentru instanțe mici de dezvoltare. Pentru producție se recomandă utilizarea altei baze de date.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dacă utilizați un client pentru sincronizarea fișierelor, utilizarea SQLite nu este recomandată.",
    "Database user" : "Utilizatorul bazei de date",
    "Database password" : "Parola bazei de date",
    "Database name" : "Numele bazei de date",
    "Database tablespace" : "Tabela de spațiu a bazei de date",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifică și numărul portului pe lângă hostname (ex: localhost;5432).",
    "Database host" : "Bază date",
    "Installing …" : "Se instalează ...",
    "Install" : "Instalează",
    "Need help?" : "Ai nevoie de ajutor?",
    "See the documentation" : "Vezi documentația",
    "{name} version {version} and above" : "{name} versiunea {version} și superioară",
    "This browser is not supported" : "Browser incompatibil",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browserul este incompatibil. Faceți upgrade la o versiune nouă.",
    "Continue with this unsupported browser" : "Continuă cu browserul incompatibil",
    "Supported versions" : "Versiuni compatibile",
    "Search {types} …" : "Căutare {types} …",
    "Choose {file}" : "Selectați {file}",
    "Choose" : "Alege",
    "Copy to {target}" : "Copiază la {target}",
    "Copy" : "Copiază",
    "Move to {target}" : "Mută la {target}",
    "Move" : "Mută",
    "OK" : "OK",
    "read-only" : "doar citire",
    "_{count} file conflict_::_{count} file conflicts_" : ["Un conflict de fişiere","{count} conflicte de fişiere","{count} conflicte de fişiere"],
    "One file conflict" : "Un conflict de fișier",
    "New Files" : "Fișiere noi",
    "Already existing files" : "Fișiere deja existente",
    "Which files do you want to keep?" : "Ce fișiere vrei să păstrezi?",
    "If you select both versions, the copied file will have a number added to its name." : "Dacă alegi ambele versiuni, fișierul copiat va avea un număr atașat la denumirea sa.",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "(all selected)" : "(toate selectate)",
    "({count} selected)" : "({count} selectate)",
    "Error loading file exists template" : "Eroare la încărcarea fișierelor șablon",
    "Saving …" : "Se salvează",
    "seconds ago" : "secunde în urmă",
    "Connection to server lost" : "S-a pierdut conexiunea la server",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleme la încărcarea paginii, se reîncarcă într-o secundă","Probleme la încărcarea paginii, se reîncarcă în câteva secunde","Probleme la încărcarea paginii, se reîncarcă în %n secunde"],
    "Add to a project" : "Adaugă la un proiect",
    "Show details" : "Arată detaliile",
    "Hide details" : "Ascunde detaliile",
    "Rename project" : "Redenumește proiectul",
    "Failed to rename the project" : "Redenumirea proiectului a eșuat",
    "Failed to create a project" : "Creearea proiectului a eșuat",
    "Failed to add the item to the project" : "Eroare la adăugarea elementului la proiect",
    "Connect items to a project to make them easier to find" : "Conectați elemente la un proiect pentru a le face mai accesibile",
    "Type to search for existing projects" : "Tastați pentru căutarea proiectelor",
    "New in" : "Nou în",
    "View changelog" : "Vezi changelog",
    "No action available" : "Nici o acțiune disponibilă",
    "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
    "Close \"{dialogTitle}\" dialog" : "Închide dialogul \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
    "Restricted" : "Restricționat",
    "Invisible" : "Invizibil",
    "Delete" : "Șterge",
    "Rename" : "Redenumește",
    "Collaborative tags" : "Etichete colaborative",
    "No tags found" : "Nu au fost găsite etichete",
    "Personal" : "Personal",
    "Accounts" : "Conturi",
    "Admin" : "Administrator",
    "Help" : "Ajutor",
    "Access forbidden" : "Acces restricționat",
    "Page not found" : "Pagina nu a fost găsită",
    "The page could not be found on the server or you may not be allowed to view it." : "Pagina nu există pe server sau nu aveți permisiunea de a o vedea.",
    "Back to %s" : "Înapoi la %s",
    "Too many requests" : "Prea multe cereri",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
    "Error" : "Eroare",
    "Internal Server Error" : "Eroare internă a serverului",
    "The server was unable to complete your request." : "Serverul nu a reușit să proceseze cererea ta.",
    "If this happens again, please send the technical details below to the server administrator." : "Dacă se repetă, te rugăm trimite detaliile tehnice către administratorul de server.",
    "More details can be found in the server log." : "Mai multe detalii pot fi găsite în jurnalul serverului.",
    "Technical details" : "Detalii tehnice",
    "Remote Address: %s" : "Adresa la distanță: %s",
    "Request ID: %s" : "ID-ul cererii: %s",
    "Type: %s" : "Tip: %s",
    "Code: %s" : "Cod: %s",
    "Message: %s" : "Mesaj: %s",
    "File: %s" : "Fișier: %s",
    "Line: %s" : "Linia: %s",
    "Trace" : "Traseu",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Se pare că doriți să reinstalați Nextcloud. Totuși, fișierul CAN_INSTALL lipsește din directorul configurației. Creați fișierul CAN_INSTALL în folderul configurației pentru a continua.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nu se poate elimina VAN_INSTALL din folderul configurației. Eliminați-l manual.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Această aplicație necesită JavaScript pentru a funcționa corect. {linkstart}Activează JavaScript{linkend} și reîncarcă pagina.",
    "Skip to main content" : "Salt la conținutul principal",
    "Skip to navigation of app" : "Salt la navigatorul aplicației",
    "Go to %s" : "Salt la %s",
    "Get your own free account" : "Obțineți contul personal gratuit",
    "Connect to your account" : "Conectează-te la contul tău",
    "Please log in before granting %1$s access to your %2$s account." : "Trebuie să vă logați înainte de a permite accesul %1$s la contul dumneavoastră %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Dacă încercați să configurați un nou device sau o aplicație, cineva încearcă să vă păcălească să-i acordați accesul la date. În acest caz nu continuați și contactați în schimb administratorul.",
    "App password" : "Parolă aplicație",
    "Grant access" : "Permite accesul",
    "Account access" : "Acces cont",
    "Currently logged in as %1$s (%2$s)." : "Autentificat ca %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Ești pe cale să permiți %1$s accesul la %2$s contul tău.",
    "Account connected" : "Cont conectat",
    "Your client should now be connected!" : "Clientul dumneavoastră ar trebui să fie conectat acum!",
    "You can close this window." : "Puteți închide această fereastră.",
    "Previous" : "Precedentul",
    "This share is password-protected" : "Această partajare este protejată cu parolă",
    "The password is wrong or expired. Please try again or request a new one." : "Parola este greșită sau a expirat. Încercați din nou sau solicitați actualizarea acesteia.",
    "Please type in your email address to request a temporary password" : "Introduceți emailul dumneavoastră pentru a solicita o parolă provizorie",
    "Email address" : "Email",
    "Password sent!" : "Parola a fost transmisă!",
    "You are not authorized to request a password for this share" : "Nu sunteți autorizat să solicitați o parolă pentru această partajare",
    "Two-factor authentication" : "Autentificare în doi-factori",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Acest cont are activată securitatea îmbunătățită. Selectați al doilea factor pentru autentificare:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nu s-a putut încărca cel puțin o metodă de autentificare în doi pași. Contactați administratorul.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Autentificarea în doi pași este activată dar nu a fost configurată pentru acest cont. Contactați administratorul pentru asistență.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Autentificarea în doi pași este activată dar nu a fost configurată pentru acest cont. Continuați configurarea acesteia.",
    "Set up two-factor authentication" : "Setează autentificarea cu doi factori",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Autentificarea în doi pași este activată dar nu a fost configurată pentru acest cont. Utilizați unul dintre codurile de backup pentru a vă autentifica sau contactați administratorul pentru asistență..",
    "Use backup code" : "Folosește un cod de backup",
    "Cancel login" : "Anulează autentificarea",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Acest contul are activată securitatea îmbunătățită. Alegeți providerul de configurat:",
    "Error while validating your second factor" : "Eroare la validarea celui de-al doilea factor",
    "Access through untrusted domain" : "Acces printr-un domeniu nesigur",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vă rugăm contactați administratorul. Dacă sunteți administrator, editați setarea \"trusted_domains\" în config/config.php la fel ca în exemplul din config.sample.php",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mai multe informații despre cum se configurează aceasta se găsește în %1$sdocumentație%2$s.",
    "App update required" : "E necesară o actualizare a aplicației",
    "%1$s will be updated to version %2$s" : "%1$sva fi actualizat la versiunea %2$s",
    "The following apps will be updated:" : "Următoarele aplicații vor fi actualizate:",
    "These incompatible apps will be disabled:" : "Aceste aplicații incompatibile vor fi dezactivate:",
    "The theme %s has been disabled." : "Tema %s a fost dezactivată.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asigură-te că ai creat un backup pentru baza de date, folderul config și folderul de date înainte de a continua.",
    "Start update" : "Începe actualizarea",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pentru a evita timeout-uri la instalări de mari dimensiuni, poți rula în schimb următoarea comandă în folderul de instalare:",
    "Detailed logs" : "Loguri detaliate",
    "Update needed" : "E necesară actualizarea",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pentru ajutor, vedeți  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentația</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Înțeleg că dacă continui să folosesc actualizarea din interfața web, există riscul ca cererea să expire și să cauzeze pierderi de date, dar am un backup și știu cum sa restaurez sesiunea în caz de eșec.",
    "Upgrade via web on my own risk" : "Actualizare prin interfața web pe riscul meu",
    "Maintenance mode" : "Mod mentenanță",
    "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
    "This page will refresh itself when the instance is available again." : "Această pagină se va actualiza automat când instanța va fi disponibilă din nou.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactează-ți administratorul de sistem dacă acest mesaj persistă sau a apărut neașteptat.",
    "Currently open" : "Deschise curent",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, apeluri video, partajare ecran, întâlniri online și videoconferințe - în browser și cu aplicația mobilă.",
    "You have not added any info yet" : "Nu ați adăugat nicio informație",
    "{user} has not added any info yet" : "{user} nu a adăugat nicio informație",
    "Error opening the user status modal, try hard refreshing the page" : "Eroare la deschiderea status utilizator, încercați refresh",
    "Edit Profile" : "Editare profil",
    "The headline and about sections will show up here" : "Secțiunile titlu și despre vor fi afișate aici",
    "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Profile not found" : "Profil inexistent",
    "The profile does not exist." : "Profilul nu există",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pentru informații despre configurarea corectă a serverului, vedeți <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentația</a>.",
    "Show password" : "Arată parola",
    "Toggle password visibility" : "Vizibilitate parolă",
    "Configure the database" : "Configurează baza de date",
    "Only %s is available." : "Doar %s este disponibil.",
    "Database account" : "Cont bază de date"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
